pub struct CompressCtx<'a, D> { /* private fields */ }Trait Implementations
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for Address
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for Address
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<RegistryKey>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<RegistryKey>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for AssetId
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for AssetId
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<RegistryKey>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<RegistryKey>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for ContractId
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for ContractId
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<RegistryKey>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<RegistryKey>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for PredicateCode
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for PredicateCode
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<RegistryKey>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<RegistryKey>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for ScriptCode
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for ScriptCode
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<RegistryKey>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<RegistryKey>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<'a, D> CompressibleBy<CompressCtx<'a, D>> for UtxoIdwhere
D: CompressDb,
impl<'a, D> CompressibleBy<CompressCtx<'a, D>> for UtxoIdwhere
D: CompressDb,
Sourceasync fn compress_with(
&self,
ctx: &mut CompressCtx<'a, D>,
) -> Result<CompressedUtxoId>
async fn compress_with( &self, ctx: &mut CompressCtx<'a, D>, ) -> Result<CompressedUtxoId>
Perform compression, returning the compressed data and possibly modifying the
context. The context is mutable to allow for stateful compression.
For instance, it can be used to extract original data when replacing it with
references.
Sourceimpl<D> ContextError for CompressCtx<'_, D>
impl<D> ContextError for CompressCtx<'_, D>